@@ -44,26 +44,25 @@ class Component(ApplicationSession):
             return a + b
 
         def stars(nick="somebody", stars=0):
-            return u"{} starred {}x".format(nick, stars)
+            return "{} starred {}x".format(nick, stars)
 
         # noinspection PyUnusedLocal
         def orders(product, limit=5):
-            return [u"Product {}".format(i) for i in range(50)][:limit]
+            return ["Product {}".format(i) for i in range(50)][:limit]
 
         def arglen(*args, **kwargs):
             return [len(args), len(kwargs)]
 
-        await self.register(ping, u'com.arguments.ping')
-        await self.register(add2, u'com.arguments.add2')
-        await self.register(stars, u'com.arguments.stars')
-        await self.register(orders, u'com.arguments.orders')
-        await self.register(arglen, u'com.arguments.arglen')
+        await self.register(ping, 'com.arguments.ping')
+        await self.register(add2, 'com.arguments.add2')
+        await self.register(stars, 'com.arguments.stars')
+        await self.register(orders, 'com.arguments.orders')
+        await self.register(arglen, 'com.arguments.arglen')
         print("Registered methods; ready for frontend.")
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
